@@ -7,6 +7,7 @@ from rest_framework.response import Response
 from wagtail.core.models import Page
 
 from django.conf.urls import url
+from django.http.response import HttpResponse
 from django.views.generic import TemplateView, View
 from molo.forms.models import MoloFormPage, FormsIndexPage, PersonalisableForm
 from molo.core.models import ArticlePage
@@ -130,6 +131,7 @@ class ResultsPercentagesJson(View):
 
 
 class FormSuccess(TemplateView):
+    is_ajax = False
     template_name = "forms/molo_form_page_success.html"
 
     def get_context_data(self, *args, **kwargs):
@@ -188,6 +190,14 @@ class FormSuccess(TemplateView):
         context.update({'self': form, 'results': results})
         return context
 
+    def dispatch(self, request, *args, **kwargs):
+        if self.is_ajax or request.GET.get('format') == 'json':
+            context = self.get_context_data(*args, **kwargs)
+            content = json.dumps(context.get('results'))
+            return HttpResponse(
+                content=content, content_type='application/json')
+        return super(FormSuccess, self).dispatch(request, *args, **kwargs)
+
 
 def submission_article(request, form_id, submission_id):
     # get the specific submission entry
